/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<backend.h>)
#  include <backend.h>
#endif
#if __has_include(<fileopen.h>)
#  include <fileopen.h>
#endif
#if __has_include(<mpris2.h>)
#  include <mpris2.h>
#endif
#if __has_include(<sandbox.h>)
#  include <sandbox.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_dragon()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Backend>("org.kde.dragon", 1);
    qmlRegisterTypesAndRevisions<BackendAttachedType>("org.kde.dragon", 1);
    qmlRegisterTypesAndRevisions<FileOpen>("org.kde.dragon", 1);
    qmlRegisterTypesAndRevisions<Mpris2>("org.kde.dragon", 1);
    qmlRegisterTypesAndRevisions<Sandbox>("org.kde.dragon", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.dragon", 1, 0);
}

static const QQmlModuleRegistration orgkdedragonRegistration("org.kde.dragon", qml_register_types_org_kde_dragon);
